@@ -1,14 +1,14 @@
-from trustar import TruStar, datetime_to_millis
-from datetime import datetime, timedelta
 import csv
-import logging
+from datetime import datetime, timedelta
+
+from trustar import datetime_to_millis, log, TruStar
 
 
 # initialize SDK
 ts = TruStar()
 
 # initialize logger
-logger = logging.getLogger(__name__)
+logger = log.get_logger(__name__)
 
 # set 'from' to the start of yesterday and 'to' to the end of yesterday
 to_time = datetime.now()
