@@ -3,16 +3,16 @@ from __future__ import print_function
 from builtins import object, str
 from future import standard_library
 from six import string_types
-import logging
 import json
 
 # package imports
+from .log import get_logger
 from .models import Tag
 
 # python 2 backwards compatibility
 standard_library.install_aliases()
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class TagClient(object):
